#!/bin/env perl

use strict;
use File::Basename qw(dirname);
use File::Find qw ( find );
use feature qw(say);
use lib qw(. Install);
use Hotfix qw(GetHostName);

use DE_EPAGES::Core::API::File qw ( CopyDirectory RunOnGlob GetFileContentLines MoveFile);
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::SystemCommand qw (SystemCommand);

sub Main {
    local $| = 1;

    chdir dirname $0;

    my $BackupDir = '../Backup-'. GetHostName();

    if (-f '../delete-files.txt') {
        foreach (@{GetFileContentLines('../delete-files.txt')}) {
            my ($Dir, $File) = split;
            next unless $File;
            next unless -e "$ENV{$Dir}/$File";
            say qq(MoveFile($ENV{$Dir}/$File, $BackupDir/$Dir/$File));
            MoveFile("$ENV{$Dir}/$File", "$BackupDir/$Dir/$File",
                     { create_directory => 1 } );
        }
    }

    return unless -d '../FileChanges';
    chdir '../FileChanges';

    return if not -d 'srv/epages/eproot' and $^O eq 'MSWin32';

    # delete language files for not installed languages
    my @InstalledLanguages;
    RunOnGlob( "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/Dictionary/Templates", 'Dictionary.*.xml', sub {
        push @InstalledLanguages, (split /\./, $_)[1];
               }
        );
    my @IgnoredLanguages;
    find(
        sub {
            return unless /\.(..)\.xml$/;
            return if $1 ~~ @InstalledLanguages;
            unlink $_;
            return if $1 ~~ @IgnoredLanguages;
            push @IgnoredLanguages, $1;
            say "ignoring: *.$1.xml";
        }, '.'
        );

    SystemCommand( '/etc/init.d/epages6 perm all -d srv/epages/eproot', { Print => 1 })
        unless $^O eq 'MSWin32';

    RunOnGlob( 'srv/epages/eproot/Cartridges/DE_EPAGES', '*/Data/WebRoot', sub {
        say qq(CopyDirectory($_, $ENV{EPAGES_WEBROOT}, $BackupDir/EPAGES_WEBROOT));
        CopyDirectory($_, $ENV{EPAGES_WEBROOT}, "$BackupDir/EPAGES_WEBROOT",
                      {by => 'perl', stat => 'preserve'});
               }
        );

    my $ShopImport = 'srv/epages/eproot/Cartridges/DE_EPAGES/ShopConfiguration/Data/Private/ShopImport';
    if (-d $ShopImport) {
        say qq(CopyDirectory($ShopImport, $ENV{EPAGES_STORES}/Site/ShopImport));
        CopyDirectory($ShopImport, "$ENV{EPAGES_STORES}/Site/ShopImport",
                      "$BackupDir/EPAGES_STORES/Site/ShopImport",
                      {by => 'perl', stat => 'preserve'});
    }

    if ($^O eq 'MSWin32') {
        say qq(CopyDirectory('srv/epages/eproot', $ENV{EPAGES}, $BackupDir/EPAGES));
        CopyDirectory('srv/epages/eproot', $ENV{EPAGES}, "$BackupDir/EPAGES");
        return;
    }

    say qq(CopyDirectory('.', '/', $BackupDir/ROOT));
    CopyDirectory('.', '/', "$BackupDir/ROOT", {by => 'perl', stat => 'preserve'});
    SystemCommand( '/etc/init.d/epages6 perm admin', { Print => 1 });
}

RunScript(
    'Sub' => \&Main
);
