#!/bin/env perl

use strict;
use File::Basename qw ( basename dirname );
use feature qw(say);

use DE_EPAGES::Core::API::Script qw ( RunScript );
use DE_EPAGES::Database::API::Config qw( StoreType GetBusinessUnits StoreTypesWithCartridge );
use DE_EPAGES::Database::API::Connection qw( RunOnStore );
use DE_EPAGES::Trigger::API::XML::HookImportHandler qw (ImportHooks);

sub Main {
    local $| = 1;

    chdir dirname $0;
    chdir '..';

    my $CustomizedImports = _GetCustomizedImports();

    my $SourceDir = 'FileChanges/srv/epages/eproot/Cartridges/DE_EPAGES';
    return unless -d $SourceDir;
    chdir $SourceDir;

    my ($Stores, $HookFiles) = _GetImports($CustomizedImports);

    foreach my $Store (@$Stores) {
        RunOnStore(
            Store => $Store,
            Sub => sub  {
                foreach (@{$HookFiles->{$Store}}) {
                    say qq(ImportHooks($_, $Store));
                    ImportHooks($_);
                }
            },
        );
    }
}

sub _GetCustomizedImports {
    my %CustomizedImports;
    foreach (glob '*XML/*/*.xml') {
        my $XMLFile = (split(m,/,))[2];
        $XMLFile =~ s/^([0-9]+-)?Hooks/Hooks/ or next;
        $CustomizedImports{(split(m,/,))[1]}{$XMLFile} = 1;
    }
    return \%CustomizedImports;
}

sub _GetImports {
    my ($CustomizedImports) = @_;

    my $BU;
    push @{$BU->{StoreType($_)}}, $_ foreach @{GetBusinessUnits({conf => 1})};

    my ($Stores, $HookFiles) = ([], {});
    foreach my $Dir (sort glob '*/Database/XML') {
        my $Cartridge = $Dir;
        $Cartridge =~ s,/.*,,;
        my @StoreTypes = @{StoreTypesWithCartridge("DE_EPAGES::$Cartridge")};

        foreach my $XMLFile (sort glob "$Dir/Hooks*.xml") {
            next if $CustomizedImports->{$Cartridge}{basename($XMLFile)};
            foreach my $StoreType (@StoreTypes) {
                foreach my $Store (@{$BU->{$StoreType}}) {
                    push @$Stores, $Store unless $Store ~~ @$Stores;
                    push @{$HookFiles->{$Store}}, "$ENV{EPAGES_CARTRIDGES}/DE_EPAGES/$XMLFile";
                }
            }
        }
    }
    return ($Stores, $HookFiles);
}

RunScript(
    'Sub' => \&Main
);
