#!/bin/env perl

use strict;
use File::Basename qw ( dirname );
use feature qw(say);

use DE_EPAGES::Core::API::Script                        qw( RunScript );
use DE_EPAGES::Core::API::File                          qw( GetFileContent );
use DE_EPAGES::Database::API::Config                    qw( GetBusinessUnits );
use DE_EPAGES::Database::API::Connection                qw( RunOnStore );
use DE_EPAGES::Database::API::DBInterface               qw( ProcessSqlGo );

RunScript(
    'Sub' => \&Main
);

sub Main {
    local $| = 1;

    chdir dirname $0;
    chdir '..';

    my $SourceDir = 'SQL';
    return unless -d $SourceDir;
    chdir $SourceDir;

    my ($Stores, $SQLFiles) = _GetSQLs();

    foreach my $Store (@$Stores) {
        RunOnStore(
            Store => $Store,
            Sub => sub  {
                foreach (@{$SQLFiles->{$Store}}) {
                    say qq(ImportSQL($_, $Store));
                    ImportSQL($_);
                }
            },
        );
    }

}

sub ImportSQL {
    my $FileName = $_;

    my $rContent = GetFileContent( $FileName );

    my $IgnoreErrors = 0;
    $IgnoreErrors = $2 if $$rContent =~ /^\s*(#|--)\s+ignore_error\s*=\s*(\S)/m;

    ProcessSqlGo( $$rContent, { ignore_error => $IgnoreErrors } );
}

sub _GetSQLs {
    my ($Stores, $SQLFiles) = ([], {});

    foreach my $Store (@{GetBusinessUnits({conf => 1})}) {
        push @$Stores, $Store unless $Store ~~ @$Stores;
        foreach my $SQLFile (sort glob 'Store/*.sql') {
            next if $Store =~ /Site/;
            push @{$SQLFiles->{$Store}}, $SQLFile;
        }
        foreach my $SQLFile (sort glob 'Site/*.sql') {
            next unless $Store =~ /Site/;
            push @{$SQLFiles->{$Store}}, $SQLFile;
        }
    }
    return ($Stores, $SQLFiles);
}
