#!/bin/env perl

use strict;
use Config::IniFiles;
use File::Basename;

use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Database::API::Config qw( StoreType GetBusinessUnits StoreTypesWithCartridge );
use DE_EPAGES::Core::API::SystemCommand qw (SystemCommand);

RunScript(
    'Sub' => \&Main
);

sub Main {
    local $| = 1;

    chdir dirname $0;
    chdir '..';

    my $ConfFile = basename $0;
    $ConfFile =~ s,^([0-9]+).*,$1.conf,;
    return unless -f "run/$ConfFile";

    my %Conf;
    tie %Conf, 'Config::IniFiles', (-file => "run/$ConfFile") or return;

    my $PerlExe = $^O eq 'MSWin32' ? $^X : "$ENV{PERL}";
    SystemCommand("$PerlExe $_", {Print => 1}) foreach @{_GetScripts(\%Conf)};
    return;
}

sub _GetScripts {
    my ($Conf) = @_;

    my @Scripts;

    my $BU;
    push @{$BU->{StoreType($_)}}, $_ foreach @{GetBusinessUnits({conf => 1})};

    foreach my $Section (sort keys %$Conf) {
        next unless $Conf->{$Section}{Script};
        next unless $Conf->{$Section}{Script} =~ /\S/;
        my $Loop = $Conf->{$Section}{Loop} // '';
        my $Cartridge = $Conf->{$Section}{Cartridge} // '';
        my $Run = _ReplaceENV("$Conf->{$Section}{Script} $Conf->{$Section}{Options}");

        if ($Loop !~ /\S/ and $Cartridge !~ /\S/) {
            # no loop, no cartridge
            push @Scripts, $Run;
        } elsif ($Loop !~ /\S/) {
            # no loop
            next unless scalar @{_StoresWithCartridge($Cartridge, $BU)};
            push @Scripts, $Run;
        } elsif ($Loop eq '-storename') {
            push @Scripts, "$Run $Loop $_" foreach @{_StoresWithCartridge($Cartridge, $BU)};
        } else {
            die "Loop not implemented yet: [$Section] -> Loop=$Loop"
                if $Loop ne '-storename';
        }
    }
    return \@Scripts;
}

sub _StoresWithCartridge ($$) {
    my ($Cartridge, $BU) = @_;

    my @Stores;
    foreach my $StoreType (@{StoreTypesWithCartridge("DE_EPAGES::$Cartridge")}) {
        push @Stores, $_ foreach @{$BU->{$StoreType}};
    }
    return \@Stores;
}

sub _ReplaceENV {
    my ($String) = @_;
    $String =~ s/\$ENV{(.*?)}/$ENV{$1}/ge;
    return $String;
}

1;
