#!/bin/env perl

use strict;
use Config::IniFiles;
use File::Basename;
use feature qw(say);

use DE_EPAGES::Core::API::Script          qw( RunScript );
use DE_EPAGES::Core::API::PerlTools       qw( UsePackage );

RunScript(
    'Sub' => \&Main
);

sub Main {
    local $| = 1;

    my $EpagesJRunning = 1;
    if ($^O ne 'MSWin32') {
        return unless -x '/etc/init.d/epagesj';
        $EpagesJRunning = 0 unless system('/etc/init.d/epagesj status') == 0;
    }

    my $EpagesJ = $ENV{EPAGESJ} // "$ENV{EPAGES}/j";
    return unless -f "$EpagesJ/webapps/epagesj.version";

    chdir dirname $0;
    chdir '..';

    my $ConfFile = basename $0;
    $ConfFile =~ s,^([0-9]+).*,$1.conf,;
    return unless -f "run/$ConfFile";
    return unless -d 'Data/j';

    my %Conf;
    tie %Conf, 'Config::IniFiles', (-file => "run/$ConfFile") or return;

    my $HotfixVersion = $Conf{'epages-j'}{hotfix_version};
    return unless $HotfixVersion;

    say qq(UpdateEpagesJ($HotfixVersion, 'Data/j', {start => $EpagesJRunning}));
    UsePackage('DE_EPAGES::Installer::API::EpagesJ');
    DE_EPAGES::Installer::API::EpagesJ::UpdateEpagesJ($HotfixVersion,
                                                      'Data/j', {start => $EpagesJRunning} );

    return unless $EpagesJRunning;

    $Conf{'epages-j'}{epagesj_updated} = $HotfixVersion;
    tied(%Conf)->RewriteConfig();

    return;
}

1;
