#!/bin/env perl

use strict;
use Config::IniFiles;
use File::Basename;
use feature qw(say);

use DE_EPAGES::Core::API::Script          qw( RunScript );
use DE_EPAGES::Database::API::Config      qw( StoreType GetBusinessUnits StoreTypesWithCartridge );
use DE_EPAGES::Database::API::Connection  qw( RunOnStore );
use DE_EPAGES::RemoteSearch::API::Object::IndexManager;
use DE_EPAGES::RemoteSearch::API::Object::IndexManagerParams;

RunScript(
    'Sub' => \&Main
);

sub Main {
    local $| = 1;

    chdir dirname $0;
    chdir '..';

    my $ConfFile = basename $0;
    $ConfFile =~ s,^([0-9]+).*,$1.conf,;
    return unless -f "run/$ConfFile";

    my %Conf;
    tie %Conf, 'Config::IniFiles', (-file => "run/$ConfFile") or return;

    return if $Conf{'epages-j'}{search_index_updated};
    return unless $Conf{'epages-j'}{epagesj_updated};
    return unless $Conf{'epages-j'}{hotfix_version};
    return unless $Conf{'epages-j'}{rebuild_search_index};

    _RebuildSearchIndex();

    $Conf{'epages-j'}{search_index_updated} = 1;
    tied(%Conf)->RewriteConfig();

    return;
}

sub _RebuildSearchIndex {
    foreach my $Store (@{_RemoteSearchStores()}) {
        RunOnStore(
            Store => $Store,
            Sub => sub  {
                    my %ManagerParams = (
                        'silent'  => 1,
                        'update'  => 1,
                        'create'  => 1,
                        'waitForCompletion' => 0,
                        );
                    my $ParamsObject = DE_EPAGES::RemoteSearch::API::Object::IndexManagerParams->new( %ManagerParams );
                    my $IndexManager = DE_EPAGES::RemoteSearch::API::Object::IndexManager->new(params => $ParamsObject);
                    say qq(DE_EPAGES::RemoteSearch::API::Object::IndexManager->manageCompleteDB($Store));
                    $IndexManager->manageCompleteDB($ParamsObject);
            },
        );
    }
}

sub _RemoteSearchStores {
    my $BU;
    push @{$BU->{StoreType($_)}}, $_ foreach @{GetBusinessUnits({conf => 1})};

    my @Stores;
    foreach my $StoreType (@{StoreTypesWithCartridge('DE_EPAGES::RemoteSearch')}) {
        push @Stores, $_ foreach @{$BU->{$StoreType}};
    }
    return \@Stores;
}
