#!/bin/env perl

use strict;
use Config::IniFiles;
use File::Basename;

use DE_EPAGES::Core::API::File qw ( GetFileContent GetFileContentLines WriteFile );
use DE_EPAGES::Database::API::Config qw( BusinessUnits );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::SystemCommand qw (SystemCommand);

sub Main {
    local $| = 1;
    return if $^O eq 'MSWin32';

    chdir dirname $0;

    my $StoreConf = BusinessUnits();
    my $BU = (keys %$StoreConf)[0];
    my $CoreVersion = $StoreConf->{$BU}{Cartridges}{'DE_EPAGES::Core'};

    my ($BaseURL, $MirrorList) = _GetRepoInfo($CoreVersion);
    _UpdateYum() if _UpdateHotfixRepo($BaseURL, $MirrorList);
}

sub _GetRepoInfo {
    my ($Version) = @_;

    my $Repo = '/etc/yum.repos.d/epages';

    my $BaseUrl = "ftp://epages-software.de/pub/products/RPMS/$Version/hotfix";
    my @MirrorList = qw(http://www.epages.com/RPMS/$Version/hotfix http://ep-server/yum/qa/$Version/hotfix);

    if (-f "$Repo-update.repo") {
        my %Conf;
        tie %Conf, 'Config::IniFiles', (-file => "$Repo-update.repo")
            or die "$Repo-update.repo: $!\n";

        if ($Conf{'epages-update'}{baseurl} =~ qw((.+)/6\.[0-9]+-update\s*$)) {
            $BaseUrl = $1. "/$Version/hotfix";
            if ($Conf{'epages-update'}{mirrorlist} =~ qw(file://(.+))) {
                @MirrorList = ();
                if (-f $1) {
                    foreach my $Line (@{GetFileContentLines($1)}) {
                        chomp $Line;
                        $Line =~ s,/6\.[0-9]+-update\s*$,/$Version/hotfix,;
                        $Line =~ s,ep-server/RPMS/,ep-server/yum/qa/,;
                        push @MirrorList, $Line if $Line =~ /\S/;
                    }
                }
            } else {
                @MirrorList = ();
            }
        }
    }

    return ($BaseUrl, \@MirrorList);
}

sub _UpdateHotfixRepo  {
    my ($BaseURL, $MirrorList) = @_;

    my $SetMirrorList = scalar @$MirrorList
        ? "\nmirrorlist = file:///etc/yum.repos.d/mirrors-epages-hotfix"
        : undef;

    my $Content = <<HERE;
### Name: ePages RPM Repository
### URL: http://epages.com/
[epages-hotfix]
name = epages.com - hotfixes
baseurl = $BaseURL$SetMirrorList
enabled = 0
gpgcheck = 1
gpgkey = file:///etc/pki/rpm-gpg/RPM-GPG-KEY-epages
HERE

    my $Repo = '/etc/yum.repos.d/epages-hotfix.repo';
    my $OldContent = -f $Repo ? GetFileContent($Repo) : \1;

    return 0 if $Content eq $$OldContent;

    WriteFile('/etc/yum.repos.d/epages-hotfix.repo',\$Content);

    if (defined $SetMirrorList) {
        $Content = join("\n", @$MirrorList). "\n";
        WriteFile('/etc/yum.repos.d/mirrors-epages-hotfix', \$Content);
    }
    return 1;
}

sub _UpdateYum {
    SystemCommand( 'cd /etc/zypp/repos.d && ln -fs /etc/yum.repos.d/epages-hotfix.repo',
                   {Print => 1} ) if -d '/etc/zypp/repos.d';
    if (-f '/etc/SuSE-release') {
        SystemCommand( 'pgrep zypper | grep -q . || zypper clean -m 2>/dev/null', {Print => 1} );
    } else {
        SystemCommand( 'pgrep yum | grep -q . || yum clean metadata', {Print => 1} );
    }
}

RunScript(
    'Sub' => \&Main
);
