#!/bin/env perl

use strict;

use DE_EPAGES::Core::API::File qw ( CorrectPathSlashes GetFileContentLines WriteFile );
use DE_EPAGES::Core::API::Error qw( ExistsError GetError Error );
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::SystemCommand qw (SystemCommand);
use DE_EPAGES::Database::API::Config qw( BusinessUnits );

sub Main {
    local $| = 1;

    my $PostInstallFile = "$ENV{EPAGES_CONFIG}/hotfixes/postinstall.txt";
    return unless -s $PostInstallFile;

    my $StoreConf = BusinessUnits();
    my $BU = (keys %$StoreConf)[0];
    my $CoreVersion = $StoreConf->{$BU}{Cartridges}{'DE_EPAGES::Core'};

    my @PostInstall = map { /^([0-9].+)/ && $1 } @{GetFileContentLines($PostInstallFile)};
    my $PerlExe = $^O eq 'MSWin32' ? $^X : "$ENV{PERL}";
    my $Dir = $ENV{EPAGES_PATCHES} // "$ENV{EPAGES_SHARED}/Patches";

    my $Error;
    while (scalar @PostInstall) {
        my $HotfixVersion = $PostInstall[0];

        if ($HotfixVersion =~ /^\Q$CoreVersion\E\./) {
            my $ScriptDir = "$Dir/epages-hotfix-$HotfixVersion/Install";
            if (glob "$ScriptDir/*-final.PL") {
                my $PerlScript = CorrectPathSlashes("$ScriptDir/install.PL");
                eval { SystemCommand( "$PerlExe $PerlScript -final", {Print => 1} ); };
                if( ExistsError() ) {
                    $Error = GetError();
                    last;
                }
            }
        }
        shift @PostInstall;
    }

    my $Content = join("\n", @PostInstall);
    WriteFile($PostInstallFile, \$Content);

    Error($Error) if $Error;
}

RunScript(
    'Sub' => \&Main
);
